<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Schließen (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Einklappen</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Ausklappen</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Alarm Beenden</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Strg+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln Wort</numerusform>
            <numerusform>%Ln Wörter</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln Minute</numerusform>
            <numerusform>%Ln Minuten</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% von %Ln Minute</numerusform>
            <numerusform>%L1% von %Ln Minuten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% von %Ln Wort</numerusform>
            <numerusform>%L1% von %Ln Wörtern</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Täglicher Fortschritt</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Längste Erfolgsserie</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Aktuelle Erfolgsserie</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n Tag</numerusform>
            <numerusform>%n Tage</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% des Tagesziels</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Sprache einstellen</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Unbenannt %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Schreibgeschützt)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Entschuldigung</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; kann nicht gespeichert werden.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Datei speichern unter</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; kann nicht überschrieben werden.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Datei umbenennen</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; kann nicht umbenannt werden.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Datei neu laden?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Datei &apos;%1&apos; von der Festplatte neu laden?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Alle ungespeicherten Änderungen werden verloren gehen.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Unbenannt %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Durch das Speichern als einfacher Text werden alle Formatierungen entfernt. Formatierungen entfernen?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Datei geändert</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Die Datei &apos;%1&apos; wurde durch ein anderes Programm geändert.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Wollen Sie die Datei neu laden?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Die Datei wurde gelöscht</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Die Datei %1 wurde von einem anderen Programm gelöscht.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Wollen Sie die Datei speichern oder schliessen?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Archiv kann nicht geöffnet werden.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Suche nach:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Ersetze durch:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Groß-/Kleinschreibung ignorieren</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Nur ganze Wörter</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Reguläre Ausrücke</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Aufwärts suchen</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Abwärts suchen</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Ersetzen</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>&amp;Alle Ersetzen</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>In %n Fall ersetzen?</numerusform>
            <numerusform>In %n Fällen ersetzen?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Entschuldigung</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Ausdruck nicht gefunden.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>nur Text</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Alle Dateien</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Alle unterstützten Dateien</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Rechtschreibung prüfen ...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(keine Vorschläge gefunden)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Programmsprache wählen:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemsprache&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Beachte</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Damit Änderungen an der Programmsprache in Kraft treten können, muss das Programm neu gestartet werden.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Archiv kann nicht geöffnet werden.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiken</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Symbolleiste</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Rechtschreibprüfung</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Wörterbuch wählen</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Entschuldigung</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Archiv kann nicht geöffnet werden.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Dieses Archiv enthält kein brauchbares Wörterbuch.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Tastaturkurzbefehle</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Ein oder mehrere Tastaturkurzbefehle wurden doppelt belegt. Möchten Sie fortfahren?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Das Wörterbuch %1 existiert bereits. Möchten Sie es ersetzen?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Tagesziel</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minuten:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Wörter:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Bearbeitung</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Immer mittig ausrichten</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Eingabemarkierung als Block darstellen</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Geglättete Schriften</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Tippgeräusche</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Typographische Anführungszeichen:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Doppelt</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Einfach</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Szenen</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Teiler:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Position der Eingabemarkierung merken</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Wörterzählung</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Seitenzählung</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Absatzzählung</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Zeichenzählung</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Zeichen:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Absätze:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algorithmus für die Wortzählung</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Tagesziel auf Null zurücksetzen?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Schreibe Bytereihenfolge-Markierung in einfache Textdateien</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Standard Format:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Heute zurücksetzen?</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Chronik</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Chronik speichern</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Erfolgsserie anzeigen</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Mindestfortschritt für Erfolgsserie:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Wortgrenzen entdecken</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Zeichenzahl durch sechs dividieren</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Jeden Buchstaben als Wort zählen</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algorithmus für die Seitenzählung</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>nur Symbole</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>nur Text</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Text neben Symbolen</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Text unter Icons</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Text Position:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Befehle</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Nach oben verschieben</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Nach unten verschieben</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Trennlinie hinzufügen</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Befehl</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Tastaturkurzbefehle</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Befehl</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Rechtschreibung bei der Eingabe prüfen</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>GROßSCHREIBUNG von Wörtern ignorieren</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Wörter mit Ziffern ignorieren</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Persönliches Wörterbuch</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Aktuelles Wörterbuch entfernen?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Benutzeroberfläche</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Immer die Bildlaufleiste zeigen</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Immer die obere Leiste zeigen</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Immer die untere Leiste zeigen</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Keine unterstützte RTF-Datei.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Ende der Datei unerwartet erreicht.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Strg+Shift+Bild nach unten</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Szenen nach oben verschieben</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Strg+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Toggle Szene Liste</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Szeneliste anzeigen (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Szeneliste verstecken (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Szenen nach unten verschieben</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Größe der Szeneliste ändern</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Sitzungen verwalten</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;itzungen</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplizieren</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Wechseln zu</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Neue Sitzung</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Sitzung duplizieren</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Sitzung umbenennen</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Sitzung löschen?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Name der Sitzung:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Entschuldigung</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Der gewählte Name für die Sitzung wird bereits verwendet.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Neu...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Strg+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Verwalten...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Strg+Shift+V</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Auf Standard zurücksetzen</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Tastaturkurzbefehl:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Anführungszeichen werden ersetzt...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Bitte warten</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Rechtschreibprüfung</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorieren</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Alle I&amp;gnorieren</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Ändern</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Alle Ä&amp;ndern</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Nicht im Wörterbuch:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Ersetzen durch:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Rechtschreibung prüfen ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Bitte warten</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Prüfung am Dateianfang fortsetzen?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Rechtschreibprüfung abgeschlossen.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Zuletzt verwendete Symbole</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Alle Symbole</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Einfügen</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blöcke</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skripte</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Unbenannt %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Kein Bild</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Gekachelt</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Zentriert</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Gedehnt</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Skaliert</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Deckkraft:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Runde Ecken des Text-Hintergrundes</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Radius:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Verschwommener Text-Hintergrund</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Schattenwurf des Text-Hintergrundes</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Vertikaler Versatz:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Ränder</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Fenster:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Seite:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Erste Zeile einrücken</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Darüber:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Darunter:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Thema bearbeiten</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Fenster-Hintergrund</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Bild:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>  Pixel</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Text-Hintergrund</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Schrift:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Schreibfehler:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Zeilenabstand</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Einzeilig</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5zeilig</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Zweizeilig</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proportional</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Absatzabstände</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Breite der Registerkarte:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Neues Thema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Themen</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Sanfter Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Alte Schule</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Weltraum-Träume</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplizieren</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Thema &apos;%1&apos; löschen?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Themen (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Thema importieren</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Thema exportieren</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Bedrückender Himmel</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Verzauberung</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Spionagespiele</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Ruhe</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Timer löschen?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Wörter:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Seiten:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Absätze:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Zeichen:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Dauer einstellen</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Uhrzeit einstellen</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Dauer:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Zeit:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Notiz:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Kein Timer eingestellt</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Letzter</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Timer einstellen abbrechen?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Themen werden geladen</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Sounds werden geladen</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Über FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Einfache Vollbild Textverarbeitung</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Herausgegeben unter der &lt;a href=%1&gt;GPL 3&lt;/a&gt; Lizenz</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Die Symbole entstammen dem &lt;a href=%1&gt;Oxygen&lt;/a&gt; Symbol-Thema</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Unter Verwendung der &lt;a href=%1&gt;LGPL 3&lt;/a&gt; Lizenz</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Zeichen: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Seiten: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Absätze: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Wörter: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Datei %1 wird geöffnet</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Unbenannt %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Alle Dokumente auflisten</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Zum nächsten Dokument wechseln</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Zum vorherigen Dokument wechseln</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Zum ersten Dokument wechseln</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Zum letzten Dokument wechseln</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Zu Dokument %1 wechseln</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Einstellungen werden geladen</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Der Sicherheitsspeicher ist nicht beschreibbar.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter wurde nicht ordnungsgemäß beendet.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Sicherheitskopie wiederherstellen?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Einige Dateien konnten nicht geöffnet werden.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Einige Dateien wurden im schreibgeschützten Modus geöffnet.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; ist aktueller als die Version im Zwischenspeicher.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Neuere Datei überschreiben?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Änderungen speichern?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Änderungen an der Datei &apos;%1&apos; vor dem Schließen speichern?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Alle Änderungen gehen verloren, wenn diese nicht gespeichert werden.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Tippgeräusche können nicht geladen werden.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Öffnen...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Neuladen</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Speichern &amp;unter...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Umbenennen...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>&amp;Alles speichern</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Sitzungen verwalten</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Neue Sitzung</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Drucken...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Strg+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Rückgängig</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Wiederholen</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>A&amp;usschneiden</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>K&amp;opieren</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Einf&amp;ügen</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>&amp;Rohtext einfügen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Strg+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Alles Ausw&amp;ählen</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Szene auswählen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Strg+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmatieren</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Fett</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Kursiv</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Unterstrichen</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Durch&amp;gestrichen</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Strg+L</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Hochgestellt</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Strg+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Tiefgestellt</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Strg+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>&amp;Linksbündig</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Strg+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Zentrieren</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Strg+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>&amp;Rechtsbündig</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Strg+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Blocksatz</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Strg+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Zeileneinzug &amp;verringern</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Strg+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>&amp;Zeile einrücken</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Strg+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Block &amp;linksbündig ausrichten</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Block &amp;rechtbündig ausrichten</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Werkzeuge</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Suchen...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>&amp;Weitersuchen</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>&amp;Rückwärts suchen</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Ersetzen...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Strg+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Anführungszeichen</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>&amp;Dokument aktualisieren</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Aus&amp;wahl aktualisieren</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Rechtschreibung...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>&amp;Sprache einstellen...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Wecker...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Symbole...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Täglicher Fortschritt</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>&amp;Symbolleiste zeigen</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>&amp;Menu Icons anzeigen</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>&amp;Hervorgehobener Text</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimieren</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Strg+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Designs...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Voreinstellungen...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Fokus Aus</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Fokus EIne Zeile</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Fokus Drei Zeilen</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Absatz</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Fokus Absatz</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Sprache...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Einige Dateien werden nicht unterstützt und können nicht geöffnet werden.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Aus</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Eine Zeile</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>Drei Zeilen</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Seiten&amp;einrichtung...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>Über&amp;schrift</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Überschrift &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Überschrift &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Überschrift &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Überschrift &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Überschrift &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Überschrift &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Typographische Anführungszeichen des Dokuments aktualisieren</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Typographische Anführungszeichen der Auswahl aktualisieren</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Strg+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>In der aktuellen Sitzung zu öffnende Dateien.</translation>
    </message>
</context>
</TS>
